summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/3rdparty/libpng/pngwio.c
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/3rdparty/libpng/pngwio.c')
-rw-r--r--experimental/tqtinterface/qt4/src/3rdparty/libpng/pngwio.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/experimental/tqtinterface/qt4/src/3rdparty/libpng/pngwio.c b/experimental/tqtinterface/qt4/src/3rdparty/libpng/pngwio.c
index dc37d3742..b39b4145f 100644
--- a/experimental/tqtinterface/qt4/src/3rdparty/libpng/pngwio.c
+++ b/experimental/tqtinterface/qt4/src/3rdparty/libpng/pngwio.c
@@ -11,7 +11,7 @@
* special handling are expected to write functions that have the same
* arguments as these and perform similar functions, but that possibly
* use different output methods. Note that you shouldn't change these
* functions, but rather write tqreplacement functions and then change
* them at run time with png_set_write_fn(...).
*/
@@ -36,7 +36,7 @@ png_write_data(png_structp png_ptr, png_bytep data, png_size_t length)
#if !defined(PNG_NO_STDIO)
/* This is the function that does the actual writing of data. If you are
- not writing to a standard C stream, you should create a tqreplacement
+ not writing to a standard C stream, you should create a replacement
write_data function and use it at run time with png_set_write_fn(), rather
than changing the library. */
#ifndef USE_FAR_KEYWORD
@@ -11,7 +11,7 @@
* arguments as these and perform similar functions, but that possibly
* use different output methods. Note that you shouldn't change these
- * functions, but rather write tqreplacement functions and then change
+ * functions, but rather write replacement functions and then change
* them at run time with png_set_write_fn(...).
*/